@@ -1,10 +1,12 @@
 data('checkerboard')
 data('checkerboard_adj')
-data("va_blocks")
-data("va18sub")
+data('va_blocks')
+data('va18sub')
 data('rockland')
 data('nrcsd')
-data("orange")
+data('orange')
 
 o_and_r <- rbind(orange, rockland)
-o_and_r <- o_and_r %>% geo_filter(nrcsd) %>% geo_trim(nrcsd)
\ No newline at end of file
+o_and_r <- o_and_r %>%
+  geo_filter(nrcsd) %>%
+  geo_trim(nrcsd)
